@@ -33,10 +33,12 @@
 
 DWIDGET_USE_NAMESPACE
 using namespace common;
+using namespace DDLog;
 
 CpuMonitor::CpuMonitor(QWidget *parent)
     : QWidget(parent)
 {
+    qCDebug(app) << "CpuMonitor constructor";
     int statusBarMaxWidth = common::getStatusBarMaxWidth();
     setFixedSize(statusBarMaxWidth, 240);
     waveformsRenderOffsetX = (statusBarMaxWidth - 140) / 2;
@@ -78,17 +80,20 @@ CpuMonitor::CpuMonitor(QWidget *parent)
 
 CpuMonitor::~CpuMonitor()
 {
+    qCDebug(app) << "CpuMonitor destructor";
     delete cpuPercents;
 }
 
 void CpuMonitor::onDetailInfoClicked()
 {
+    qCDebug(app) << "onDetailInfoClicked";
     setDetailButtonVisible(false);
     emit signalDetailInfoClicked();
 }
 
 void CpuMonitor::setDetailButtonVisible(bool visible)
 {
+    qCDebug(app) << "setDetailButtonVisible:" << visible;
     m_detailButton->setVisible(visible);
 }
 
@@ -99,9 +104,11 @@ void CpuMonitor::changeTheme(DApplicationHelper::ColorType themeType)
 void CpuMonitor::changeTheme(DGuiApplicationHelper::ColorType themeType)
 {
 #endif
+    qCDebug(app) << "changeTheme with themeType:" << themeType;
     switch (themeType) {
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     case DApplicationHelper::LightType:
+        qCDebug(app) << "LightType";
 #else
     case DGuiApplicationHelper::LightType:
 #endif
@@ -110,6 +117,7 @@ void CpuMonitor::changeTheme(DGuiApplicationHelper::ColorType themeType)
         break;
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     case DApplicationHelper::DarkType:
+        qCDebug(app) << "DarkType";
 #else
     case DGuiApplicationHelper::DarkType:
 #endif
@@ -117,6 +125,7 @@ void CpuMonitor::changeTheme(DGuiApplicationHelper::ColorType themeType)
         m_icon = QIcon(iconPathFromQrc("dark/icon_cpu_light.svg"));
         break;
     default:
+        qCDebug(app) << "default theme type";
         break;
     }
 
@@ -139,9 +148,12 @@ void CpuMonitor::changeTheme(DGuiApplicationHelper::ColorType themeType)
 
 void CpuMonitor::updateStatus()
 {
+    qCDebug(app) << "updateStatus";
     // 如果数据无效不更新
-    if (std::isnan(m_cpuInfomodel->cpuAllPercent()))
+    if (std::isnan(m_cpuInfomodel->cpuAllPercent())) {
+        qCWarning(app) << "cpuAllPercent is nan";
         return;
+    }
     cpuPercents->append(m_cpuInfomodel->cpuAllPercent());
 
     if (cpuPercents->size() > pointsNumber) {
@@ -161,6 +173,7 @@ void CpuMonitor::updateStatus()
         if (cpuMaxHeight < cpuRenderMaxHeight) {
             points.append(QPointF(i * 5 - 8, cpuPercents->at(i)));
         } else {
+            // qCDebug(app) << "cpuMaxHeight >= cpuRenderMaxHeight";
             points.append(
                 QPointF(i * 5 - 8, cpuPercents->at(i) * cpuRenderMaxHeight / cpuMaxHeight));
         }
@@ -173,6 +186,7 @@ void CpuMonitor::updateStatus()
 
 void CpuMonitor::changeFont(const QFont &font)
 {
+    qCDebug(app) << "changeFont";
     m_cpuUsageFont = font;
     m_cpuUsageFont.setBold(true);
     m_cpuUsageFont.setPointSizeF(m_cpuUsageFont.pointSizeF() + 3);
@@ -189,12 +203,14 @@ void CpuMonitor::changeFont(const QFont &font)
 
 void CpuMonitor::resizeEvent(QResizeEvent *event)
 {
+    // qCDebug(app) << "resizeEvent";
     QWidget::resizeEvent(event);
     resizeItemWidgetRect();
 }
 
 void CpuMonitor::resizeItemWidgetRect()
 {
+    // qCDebug(app) << "resizeItemWidgetRect";
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     m_detailButton->setFixedSize(m_detailButton->fontMetrics().width(m_detailButton->text()) + 16, m_detailButton->fontMetrics().height() + 4);
 #else
@@ -206,6 +222,7 @@ void CpuMonitor::resizeItemWidgetRect()
 
 void CpuMonitor::paintEvent(QPaintEvent *)
 {
+    // qCDebug(app) << "paintEvent";
     QPainter painter(this);
     painter.setRenderHint(QPainter::Antialiasing, true);
 
@@ -262,12 +279,16 @@ void CpuMonitor::paintEvent(QPaintEvent *)
 
 void CpuMonitor::mouseReleaseEvent(QMouseEvent *ev)
 {
-    if (ev->button() == Qt::LeftButton)
+    // qCDebug(app) << "mouseReleaseEvent";
+    if (ev->button() == Qt::LeftButton) {
+        // qCDebug(app) << "mouseReleaseEvent left button";
         emit clicked("MSG_CPU");
+    }
 }
 
 void CpuMonitor::mouseMoveEvent(QMouseEvent *event)
 {
+    // qCDebug(app) << "mouseMoveEvent";
     Q_UNUSED(event);
     return;
 }
