@@ -24,7 +24,12 @@
 #include "helper.hpp"
 
 #include <DApplication>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <DApplicationHelper>
+#else
+#include <DGuiApplicationHelper>
+#include <DPaletteHelper>
+#endif
 #include <DDialog>
 #include <DErrorMessage>
 #include <DFontSizeManager>
@@ -46,6 +51,7 @@
 #include <QTimer>
 #include <QKeyEvent>
 #include <QShortcut>
+#include <QActionGroup>
 
 using namespace DDLog;
 using namespace common::init;
@@ -61,6 +67,7 @@ static QMetaObject::Connection m_pControlConnection = QMetaObject::Connection();
 ProcessTableView::ProcessTableView(DWidget *parent, QString userName)
     : BaseTableView(parent), m_useModeName(userName)
 {
+    qCDebug(app) << "ProcessTableView created with userName:" << userName;
     // install event filter for table view to handle key events
     installEventFilter(this);
 
@@ -77,7 +84,11 @@ ProcessTableView::ProcessTableView(DWidget *parent, QString userName)
     initConnections(settingsLoaded);
     // adjust search result tip label text color dynamically on theme type change
     onThemeTypeChanged();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged, this, &ProcessTableView::onThemeTypeChanged);
+#else
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &ProcessTableView::onThemeTypeChanged);
+#endif
     if (!userName.isNull()) {
         m_cpuUsage = m_model->getTotalCPUUsage();
         m_memUsage = m_model->getTotalMemoryUsage();
@@ -93,28 +104,37 @@ ProcessTableView::ProcessTableView(DWidget *parent, QString userName)
 // destructor
 ProcessTableView::~ProcessTableView()
 {
+    qCDebug(app) << "ProcessTableView destroyed";
     // backup table view settings
     saveSettings();
 }
 
 void ProcessTableView::onThemeTypeChanged()
 {
+    qCDebug(app) << "ProcessTableView onThemeTypeChanged";
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     auto palette = DApplicationHelper::instance()->applicationPalette();
+#else
+    auto palette = DGuiApplicationHelper::instance()->applicationPalette();
+#endif
     palette.setColor(DPalette::Text, palette.color(DPalette::PlaceholderText));
     m_notFoundLabel->setPalette(palette);
 }
 
 QString ProcessTableView::getProcessName(int pid)
 {
+    qCDebug(app) << "Getting process name for pid:" << pid;
     return m_model->getProcess(qvariant_cast<pid_t>(pid)).name();
 }
 
 // event filter
 bool ProcessTableView::eventFilter(QObject *obj, QEvent *event)
 {
+    // qCDebug(app) << "ProcessTableView eventFilter";
     // handle key press events for process table view
     if (obj == this) {
         if (event->type() == QEvent::KeyPress) {
+            qCDebug(app) << "ProcessTableView eventFilter: KeyPress";
             auto *kev = dynamic_cast<QKeyEvent *>(event);
             // ALT+M show context menu
             if (kev->modifiers() == Qt::ALT && kev->key() == Qt::Key_M) {
@@ -140,11 +160,14 @@ bool ProcessTableView::eventFilter(QObject *obj, QEvent *event)
 // end process handler
 void ProcessTableView::endProcess()
 {
+    qCDebug(app) << "Attempting to end process with selected PID:" << m_selectedPID;
     // no selected item, do nothing
     if (m_selectedPID.isNull()) {
+        qCDebug(app) << "No process selected for ending";
         return;
     }
 
+    qCDebug(app) << "Showing end process confirmation dialog for PID:" << m_selectedPID;
     // kill confirm dialog title & description
     QString title = DApplication::translate("Kill.Process.Dialog", "End process");
     QString description = DApplication::translate("Kill.Process.Dialog",
@@ -152,14 +175,15 @@ void ProcessTableView::endProcess()
                                                   "loss.\nAre you sure you want to continue?");
 
     KillProcessConfirmDialog dialog(this);
-    //    dialog.setTitle(title);
     dialog.setMessage(description);
     dialog.addButton(DApplication::translate("Kill.Process.Dialog", "Cancel", "button"), false);
     dialog.addButton(DApplication::translate("Kill.Process.Dialog", "End", "button"), true,
                      DDialog::ButtonWarning);
     dialog.exec();
     if (dialog.result() == QMessageBox::Ok) {
+        qCDebug(app) << "ProcessTableView endProcess: User confirmed ending process";
         Process proc = m_model->getProcess(qvariant_cast<pid_t>(m_selectedPID));
+        qCDebug(app) << "User confirmed ending process:" << proc.name() << "(" << m_selectedPID << ")";
         QJsonObject obj {
             { "tid", EventLogUtils::ProcessKilled },
             { "version", QCoreApplication::applicationVersion() },
@@ -169,45 +193,54 @@ void ProcessTableView::endProcess()
 
         ProcessDB::instance()->endProcess(qvariant_cast<pid_t>(m_selectedPID));
     } else {
-        return;
+        qCDebug(app) << "User cancelled ending process:" << m_selectedPID;
     }
 }
 
 // pause process handler
 void ProcessTableView::pauseProcess()
 {
+    qCDebug(app) << "Attempting to pause process with selected PID:" << m_selectedPID;
     auto pid = qvariant_cast<pid_t>(m_selectedPID);
     // no selected item or app self been selected, then do nothing
     if (m_selectedPID.isNull() || ProcessDB::instance()->isCurrentProcess(pid)) {
+        qCDebug(app) << "Cannot pause process - no selection or current process";
         return;
     }
+    qCDebug(app) << "Pausing process:" << pid;
     ProcessDB::instance()->pauseProcess(pid);
 }
 
 // resume process handler
 void ProcessTableView::resumeProcess()
 {
+    qCDebug(app) << "Attempting to resume process with selected PID:" << m_selectedPID;
     auto pid = qvariant_cast<pid_t>(m_selectedPID);
     //no selected item or app self been selected, then do nothing
     if (m_selectedPID.isNull() || ProcessDB::instance()->isCurrentProcess(pid)) {
+        qCDebug(app) << "Cannot resume process - no selection or current process";
         return;
     }
 
+    qCDebug(app) << "Resuming process:" << pid;
     ProcessDB::instance()->resumeProcess(pid);
 }
 
 // open process bin path in file manager
 void ProcessTableView::openExecDirWithFM()
 {
+    qCDebug(app) << "Attempting to open exec directory for selected PID:" << m_selectedPID;
     // selection check needed
     if (m_selectedPID.isValid()) {
         pid_t pid = qvariant_cast<pid_t>(m_selectedPID);
         const Process &proc = ProcessDB::instance()->processSet()->getProcessById(pid);
         QString cmdline = proc.cmdlineString();
 
+        qCDebug(app) << "Opening exec directory for process:" << proc.name() << "(" << pid << ")";
         if (cmdline.size() > 0) {
             // Found wine program location if cmdline starts with c://.
             if (cmdline.startsWith("c:")) {
+                qCDebug(app) << "Found wine program, using wine prefix path";
                 QString winePrefix = proc.environ().value("WINEPREFIX");
                 cmdline = cmdline.replace("\\", "/").replace("c:/", "/drive_c/");
 
@@ -217,6 +250,7 @@ void ProcessTableView::openExecDirWithFM()
                 QString flatpakAppidEnv = proc.environ().value("FLATPAK_APPID");
                 // Else find program location through 'which' command.
                 if (flatpakAppidEnv == "") {
+                    qCDebug(app) << "Using which command to find program location";
                     QProcess whichProcess;
                     QString exec = "which";
                     QStringList params;
@@ -230,12 +264,14 @@ void ProcessTableView::openExecDirWithFM()
                         path = QString(output.split("\n")[0]).trimmed();
                         // 读取persistent目录
                         if (path.isEmpty()) {
+                            qCDebug(app) << "Path empty, checking namespace";
                             char nsPath[PATH_MAX] = { 0 }, nsSelfPath[PATH_MAX] = { 0 };
                             auto nsSize = readlink(QString("/proc/%1/ns/pid").arg(pid).toStdString().c_str(), nsPath, PATH_MAX);
                             auto nsSelfSize = readlink(QString("/proc/self/ns/pid").toStdString().c_str(), nsSelfPath, PATH_MAX);
                             if (nsSize > 0 && nsSelfSize > 0) {
                                 QString nsPathStr(nsPath), nsSelfPathStr(nsSelfPath);
                                 if (nsPathStr != nsSelfPathStr) {
+                                    qCDebug(app) << "Different namespace detected, searching for parent process";
                                     Process preProc = proc, curProc = proc;
                                     int count = 0;
                                     // 100次循环
@@ -246,6 +282,7 @@ void ProcessTableView::openExecDirWithFM()
                                     }
                                     if (curProc.pid() != 0 || count != 100) {
                                         pid = preProc.pid();
+                                        qCDebug(app) << "Found parent process:" << pid;
                                     }
                                     char exePath[PATH_MAX] = { 0 };
                                     auto exeSize = readlink(QString("/proc/%1/exe").arg(pid).toStdString().c_str(), exePath, PATH_MAX);
@@ -256,11 +293,16 @@ void ProcessTableView::openExecDirWithFM()
                                             QString devStr;
                                             do {
                                                 QString line = file.readLine();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                                                 auto works = line.split(" ", QString::SkipEmptyParts);
+#else
+                                                auto works = line.split(" ", Qt::SkipEmptyParts);
+#endif
                                                 if (works.size() > 9 && exeStr.startsWith(works[4]) && works[9].startsWith("/dev")) {
                                                     devStr = works[9];
                                                     if (!devStr.isEmpty()) {
                                                         path = "/persistent" + works[3] + exeStr.right(exeStr.size() - works[4].size());
+                                                        qCDebug(app) << "Found persistent path:" << path;
                                                     }
                                                     break;
                                                 }
@@ -278,6 +320,7 @@ void ProcessTableView::openExecDirWithFM()
                 }
                 // Find flatpak application location.
                 else {
+                    qCDebug(app) << "Found flatpak application, using flatpak info";
                     QProcess whichProcess;
                     QString exec = "flatpak";
                     QStringList params;
@@ -291,6 +334,7 @@ void ProcessTableView::openExecDirWithFM()
                     if (flatpakRootDir.cd("files") && flatpakRootDir.cd("bin")) {
                         // Need split full path to get last filename.
                         const QString &path = QString(flatpakRootDir.absoluteFilePath(cmdline.split("/").last())).trimmed();
+                        qCDebug(app) << "Found flatpak path:" << path;
                         common::openFilePathItem(path);
                     }
                 }
@@ -302,11 +346,13 @@ void ProcessTableView::openExecDirWithFM()
 // show process attribute dialog
 void ProcessTableView::showProperties()
 {
+    qCDebug(app) << "Showing properties for selected PID:" << m_selectedPID;
     // selection valid check
     if (m_selectedPID.isValid()) {
         pid_t pid = qvariant_cast<pid_t>(m_selectedPID);
         // get process entry item from model
         auto proc = m_model->getProcess(pid);
+        qCDebug(app) << "Showing properties for process:" << proc.name() << "(" << pid << ")";
         auto *attr = new ProcessAttributeDialog(pid,
                                                 proc.name(),
                                                 proc.displayName(),
@@ -321,11 +367,14 @@ void ProcessTableView::showProperties()
 // kill process handler
 void ProcessTableView::killProcess()
 {
+    qCDebug(app) << "Attempting to kill process with selected PID:" << m_selectedPID;
     // no selected item, do nothing
     if (m_selectedPID.isNull()) {
+        qCDebug(app) << "No process selected for killing";
         return;
     }
 
+    qCDebug(app) << "Showing kill process confirmation dialog for PID:" << m_selectedPID;
     // dialog
     QString title = DApplication::translate("Kill.Process.Dialog", "End process");
     QString description = DApplication::translate("Kill.Process.Dialog",
@@ -341,6 +390,7 @@ void ProcessTableView::killProcess()
     dialog.exec();
     if (dialog.result() == QMessageBox::Ok) {
         Process proc = m_model->getProcess(qvariant_cast<pid_t>(m_selectedPID));
+        qCDebug(app) << "User confirmed killing process:" << proc.name() << "(" << m_selectedPID << ")";
         QJsonObject obj {
             { "tid", EventLogUtils::ProcessKilled },
             { "version", QCoreApplication::applicationVersion() },
@@ -349,13 +399,14 @@ void ProcessTableView::killProcess()
         EventLogUtils::get().writeLogs(obj);
         ProcessDB::instance()->killProcess(qvariant_cast<pid_t>(m_selectedPID));
     } else {
-        return;
+        qCDebug(app) << "User cancelled killing process:" << m_selectedPID;
     }
 }
 
 // filter process table based on searched text
 void ProcessTableView::search(const QString &text)
 {
+    qCDebug(app) << "Searching for text:" << text;
     m_proxyModel->setSortFilterString(text);
     // adjust search result tip label's visibility & position if needed
     adjustInfoLabelVisibility();
@@ -365,22 +416,26 @@ void ProcessTableView::search(const QString &text)
 // switch process table view display mode
 void ProcessTableView::switchDisplayMode(FilterType type)
 {
-
+    qCDebug(app) << "Switching display mode to:" << type;
     m_proxyModel->setFilterType(type);
 }
 
 // change process priority
 void ProcessTableView::changeProcessPriority(int priority)
 {
+    qCDebug(app) << "Changing process priority for selected PID:" << m_selectedPID << "to" << priority;
     // check selection first
     if (m_selectedPID.isValid()) {
         pid_t pid = qvariant_cast<pid_t>(m_selectedPID);
 
         // if no changes in priority value, then do nothing
         auto prio = m_model->getProcessPriority(pid);
-        if (prio == priority)
+        if (prio == priority) {
+            qCDebug(app) << "Priority unchanged for process:" << pid;
             return;
+        }
 
+        qCDebug(app) << "Changing priority for process:" << pid << "from" << prio << "to" << priority;
         ProcessDB::instance()->setProcessPriority(pid, priority);
     }
 }
@@ -388,6 +443,7 @@ void ProcessTableView::changeProcessPriority(int priority)
 // load & restore table view settings from backup storage
 bool ProcessTableView::loadSettings(const QString &flag)
 {
+    qCDebug(app) << "Loading settings with flag:" << flag;
     Settings *s = Settings::instance();
     if (s) {
         const QVariant &opt = s->getOption(flag);
@@ -396,18 +452,22 @@ bool ProcessTableView::loadSettings(const QString &flag)
             const QByteArray &buf = QByteArray::fromBase64(opt.toByteArray());
             if (buf.endsWith(header_version)) {
                 header()->restoreState(buf);
+                qCDebug(app) << "Settings loaded successfully";
                 return true;
             } else {
+                qCWarning(app) << "Settings version mismatch";
                 return false;
             }
         }
     }
+    qCDebug(app) << "No settings found";
     return false;
 }
 
 // save table view settings to backup storage
 void ProcessTableView::saveSettings()
 {
+    qCDebug(app) << "Saving settings";
     Settings *s = Settings::instance();
     if (s) {
         QByteArray buf = header()->saveState();
@@ -426,14 +486,18 @@ void ProcessTableView::saveSettings()
 // initialize ui components
 void ProcessTableView::initUI(bool settingsLoaded)
 {
-
+    qCDebug(app) << "Initializing UI components";
     setAccessibleName("ProcessTableView");
 
     // search result not found tip label instance
     m_notFoundLabel = new DLabel(DApplication::translate("Common.Search", "No search results"), this);
     DFontSizeManager::instance()->bind(m_notFoundLabel, DFontSizeManager::T4);
     // change text color
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     auto palette = DApplicationHelper::instance()->palette(m_notFoundLabel);
+#else
+    auto palette = DPaletteHelper::instance()->palette(m_notFoundLabel);
+#endif
     QColor labelColor = palette.color(DPalette::PlaceholderText);
     palette.setColor(DPalette::Text, labelColor);
     m_notFoundLabel->setPalette(palette);
@@ -470,6 +534,7 @@ void ProcessTableView::initUI(bool settingsLoaded)
 
     // if no backup settings loaded, show default style
     if (!settingsLoaded) {
+        qCDebug(app) << "No settings loaded, using default style";
         // proc name
         setColumnWidth(ProcessTableModel::kProcessNameColumn, 300);
         setColumnHidden(ProcessTableModel::kProcessNameColumn, false);
@@ -530,6 +595,7 @@ void ProcessTableView::initUI(bool settingsLoaded)
 // initialize connections
 void ProcessTableView::initConnections(bool settingsLoaded)
 {
+    qCDebug(app) << "Initializing connections";
     auto *mainWindow = gApp->mainWindow();
     // connect search slot to toolbar's search signal
     connect(mainWindow->toolbar(), &Toolbar::search, this, &ProcessTableView::search);
@@ -791,6 +857,7 @@ void ProcessTableView::initConnections(bool settingsLoaded)
 
     // set default header context menu checkable state when settings load without success
     if (!settingsLoaded) {
+        qCDebug(app) << "Settings not loaded, using default header context menu checkable state";
         cpuHeaderAction->setChecked(true);
         memHeaderAction->setChecked(true);
         sharememHeaderAction->setChecked(false);
@@ -876,6 +943,7 @@ void ProcessTableView::initConnections(bool settingsLoaded)
     connect(ProcessDB::instance(), &ProcessDB::priorityPromoteResultReady, this,
             [=](const ErrorContext &ec) {
                 if (ec) {
+                    qCWarning(app) << "Failed to change priority:" << ec.getErrorName() << "-" << ec.getErrorMessage();
                     ErrorDialog::show(this, ec.getErrorName(), ec.getErrorMessage());
                 }
             });
@@ -886,8 +954,8 @@ void ProcessTableView::initConnections(bool settingsLoaded)
         m_pControlConnection = connect(ProcessDB::instance(), &ProcessDB::processControlResultReady, this,
                                        [=](const ErrorContext &ec) {
                                            if (ec) {
+                                               qCWarning(app) << "Process control failed:" << ec.getErrorName() << "-" << ec.getErrorMessage();
                                                ErrorDialog::show(this, ec.getErrorName(), ec.getErrorMessage());
-                                               qCWarning(app) << "ErrorName: " << ec.getErrorName() << ",ErrorMessage: " << ec.getErrorMessage();
                                            }
                                        });
 }
@@ -895,8 +963,11 @@ void ProcessTableView::initConnections(bool settingsLoaded)
 // show process table view context menu on specified positon
 void ProcessTableView::displayProcessTableContextMenu(const QPoint &p)
 {
-    if (selectedIndexes().size() == 0)
+    qCDebug(app) << "Displaying process table context menu";
+    if (selectedIndexes().size() == 0) {
+        qCDebug(app) << "No process selected for context menu";
         return;
+    }
 
     QPoint point = mapToGlobal(p);
     point.setY(point.y() + header()->sizeHint().height());
@@ -906,12 +977,14 @@ void ProcessTableView::displayProcessTableContextMenu(const QPoint &p)
 // show process header view context menu on specified position
 void ProcessTableView::displayProcessTableHeaderContextMenu(const QPoint &p)
 {
+    qCDebug(app) << "Displaying process table header context menu";
     m_headerContextMenu->popup(mapToGlobal(p));
 }
 
 // resize event handler
 void ProcessTableView::resizeEvent(QResizeEvent *event)
 {
+    // qCDebug(app) << "Resizing process table view";
     // adjust search result tip label's visibility & position when resizing
     adjustInfoLabelVisibility();
 
@@ -921,6 +994,7 @@ void ProcessTableView::resizeEvent(QResizeEvent *event)
 // show event handler
 void ProcessTableView::showEvent(QShowEvent *)
 {
+    // qCDebug(app) << "Showing process table view";
     // hide search result not found on initial show
     if (m_notFoundLabel) {
         m_notFoundLabel->hide();
@@ -931,8 +1005,10 @@ void ProcessTableView::showEvent(QShowEvent *)
 void ProcessTableView::selectionChanged(const QItemSelection &selected,
                                         const QItemSelection &deselected)
 {
+    qCDebug(app) << "Selection changed in process table view";
     // if no selection, do nothing
     if (selected.size() <= 0) {
+        qCDebug(app) << "No selection in process table view";
         return;
     }
 
@@ -944,6 +1020,7 @@ void ProcessTableView::selectionChanged(const QItemSelection &selected,
 // return hinted size for specified column, so column can be resized to a prefered width when double clicked
 int ProcessTableView::sizeHintForColumn(int column) const
 {
+    qCDebug(app) << "Getting size hint for column" << column;
     int margin = 10;
     return std::max(header()->sizeHintForColumn(column) + margin * 2,
                     DTreeView::sizeHintForColumn(column) + margin * 2);
@@ -952,6 +1029,7 @@ int ProcessTableView::sizeHintForColumn(int column) const
 // adjust search result tip label's visibility & position
 void ProcessTableView::adjustInfoLabelVisibility()
 {
+    qCDebug(app) << "Adjusting search result tip label visibility";
     setUpdatesEnabled(false);
     // show search not found label only when proxy model is empty & search text input is none empty
     m_notFoundLabel->setVisible(m_proxyModel->rowCount() == 0
@@ -965,6 +1043,7 @@ void ProcessTableView::adjustInfoLabelVisibility()
 // show customize process priority dialog
 void ProcessTableView::customizeProcessPriority()
 {
+    qCDebug(app) << "Customizing process priority";
     // priority dialog instance
     DDialog *prioDialog = new DDialog(this);
     prioDialog->setIcon(QIcon::fromTheme("dialog-warning"));
@@ -988,6 +1067,7 @@ void ProcessTableView::customizeProcessPriority()
     // set initial slider & tip value based on current process priority
     QString prio { "0" };
     if (m_selectedPID.isValid()) {
+        qCDebug(app) << "Selected PID is valid:" << m_selectedPID;
         pid_t pid = qvariant_cast<pid_t>(m_selectedPID);
         slider->setValue(m_model->getProcessPriorityValue(pid));
         Process selectedProcess = m_model->getProcess(pid);
@@ -998,6 +1078,7 @@ void ProcessTableView::customizeProcessPriority()
         slider->setValue(selectedPriority);
         prio = QString("%1").arg(slider->value());
         slider->setTipValue(prio);
+        qCDebug(app) << "Setting initial priority value:" << selectedPriority << "for process:" << pid;
     }
     prioDialog->addContent(slider);
     prioDialog->addSpacing(16);
@@ -1010,9 +1091,11 @@ void ProcessTableView::customizeProcessPriority()
     connect(prioDialog, &DDialog::buttonClicked, this, [=](int index, QString text) {
         Q_UNUSED(text);
         if (index == 1) {
+            qCDebug(app) << "User confirmed priority change to:" << slider->value();
             changeProcessPriority(slider->value());
             prioDialog->setResult(QMessageBox::Ok);
         } else {
+            qCDebug(app) << "User cancelled priority change";
             prioDialog->setResult(QMessageBox::Cancel);
         }
     });
@@ -1021,7 +1104,9 @@ void ProcessTableView::customizeProcessPriority()
 
 void ProcessTableView::setUserModeName(const QString &userName)
 {
+    qCDebug(app) << "Current user mode name:" << m_useModeName;
     if (userName != m_useModeName) {
+        qCDebug(app) << "Setting user mode name to:" << userName;
         m_useModeName = userName;
         m_model->setUserModeName(m_useModeName);
     }
