@@ -4,6 +4,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "process.h"
+#include "ddlog.h"
 #include "private/process_p.h"
 #include "system/device_db.h"
 #include "process/process_db.h"
@@ -42,12 +43,14 @@ using namespace common::init;
 using namespace common::core;
 using namespace common::error;
 using namespace core::system;
+using namespace DDLog;
 
 namespace core {
 namespace process {
 
 QString getPriorityName(int prio)
 {
+    qCDebug(app) << "Getting priority name for value:" << prio;
     const static QMap<ProcessPriority, QString> priorityMap = {
         {kVeryHighPriority, QApplication::translate("Process.Priority", "Very high")},
         {kHighPriority, QApplication::translate("Process.Priority", "High")},
@@ -65,11 +68,13 @@ QString getPriorityName(int prio)
         p = kCustomPriority;
     }
 
+    qCDebug(app) << "Priority maps to:" << priorityMap[p];
     return priorityMap[p];
 }
 
 ProcessPriority getProcessPriorityStub(int prio)
 {
+    qCDebug(app) << "Getting process priority stub for value:" << prio;
     if (prio == 0) {
         return kNormalPriority;
     } else if (prio == kVeryHighPriority || prio == kHighPriority || prio == kLowPriority || prio == kVeryLowPriority) {
@@ -84,21 +89,24 @@ ProcessPriority getProcessPriorityStub(int prio)
 Process::Process()
     : d(new ProcessPrivate())
 {
-
+    qCDebug(app) << "Process object created";
 }
 Process::Process(pid_t pid)
     : d(new ProcessPrivate())
 {
+    qCDebug(app) << "Process object created for pid" << pid;
     d->pid = pid;
 }
 Process::Process(const Process &other)
     : d(other.d)
 {
+    qCDebug(app) << "Process object copied from pid" << other.d->pid;
 }
 Process &Process::operator=(const Process &rhs)
 {
     if (this == &rhs)
         return *this;
+    // qCDebug(app) << "Process object assigned from pid" << rhs.d->pid;
 
     d = rhs.d;
     return *this;
@@ -106,26 +114,30 @@ Process &Process::operator=(const Process &rhs)
 
 Process::~Process()
 {
+    qCDebug(app) << "Process object destroyed for pid" << (d ? d->pid : -1);
 }
 
 time_t Process::startTime() const
 {
     auto *monitor = ThreadManager::instance()->thread<SystemMonitorThread>(BaseThread::kSystemMonitorThread)->systemMonitorInstance();
-    return monitor->sysInfo()->btime().tv_sec + time_t(d->start_time / HZ);
+    time_t st = monitor->sysInfo()->btime().tv_sec + time_t(d->start_time / HZ);
+    qCDebug(app) << "Start time for pid" << d->pid << "is" << st;
+    return st;
 }
 
 timeval Process::procuptime() const
 {
+    qCDebug(app) << "Process uptime for pid" << d->pid << "is" << d->uptime.tv_sec << "s";
     return d->uptime;
 }
 
 void Process::readProcessVariableInfo()
 {
+    qCDebug(app) << "Reading variable info for pid" << d->pid;
     d->valid = true;
 
     bool ok = true;
     ok = ok && readStat();
-//    readEnviron();
     readSchedStat();
     ok = ok && readStatm();
 
@@ -142,6 +154,7 @@ void Process::readProcessVariableInfo()
     auto validrecentPtr = recentProcptr.lock();
     qreal timedelta = d->stime + d->utime;
     if (validrecentPtr) {
+        qCDebug(app) << "Found recent process stage for pid" << d->pid;
         timedelta = timedelta - validrecentPtr->ptime;
         struct DiskIO io = {validrecentPtr->read_bytes, validrecentPtr->write_bytes, validrecentPtr->cancelled_write_bytes};
         d->diskIOSample->addSample(new DISKIOSampleFrame(validrecentPtr->uptime, io));
@@ -175,13 +188,15 @@ void Process::readProcessVariableInfo()
     d->networkBandwidthSample->addSample(new IOPSSampleFrame(netiops));
 
     d->valid = d->valid && ok;
+    qCDebug(app) << "Finished reading variable info for pid" << d->pid << "valid:" << d->valid;
 }
 
 void Process::readProcessSimpleInfo()
 {
+    qCDebug(app) << "Reading simple info for pid" << d->pid;
     d->valid = true;
     bool ok = true;
-readEnviron();
+    readEnviron();
     ok = ok && readStat();
     ok = ok && readStatus();
     ok = ok && readCmdline();
@@ -197,16 +212,20 @@ readEnviron();
     if (euid == d->uid && (wmwindowList->isGuiApp(d->pid)
                            || wmwindowList->isTrayApp(d->pid)
                            || wmwindowList->isDesktopEntryApp(d->pid))) {
+        qCDebug(app) << "Process" << d->pid << "is a GUI/Tray/Desktop app";
         d->apptype = kFilterApps;
     } else if (euid == d->uid) {
+        qCDebug(app) << "Process" << d->pid << "is a current user app";
         d->apptype = kFilterCurrentUser;
     }
 
     d->valid = d->valid && ok;
+    qCDebug(app) << "Finished reading simple info for pid" << d->pid << "valid:" << d->valid;
 }
 
 void Process::readProcessInfo()
 {
+    qCDebug(app) << "Reading full process info for pid" << d->pid;
     d->valid = true;
 
     bool ok = true;
@@ -232,6 +251,7 @@ void Process::readProcessInfo()
     auto validrecentPtr = recentProcptr.lock();
     qreal timedelta = d->stime + d->utime;
     if (validrecentPtr) {
+        qCDebug(app) << "Found recent process stage for pid" << d->pid;
         timedelta = timedelta - validrecentPtr->ptime;
         struct DiskIO io = {validrecentPtr->read_bytes, validrecentPtr->write_bytes, validrecentPtr->cancelled_write_bytes};
         d->diskIOSample->addSample(new DISKIOSampleFrame(validrecentPtr->uptime, io));
@@ -254,8 +274,10 @@ void Process::readProcessInfo()
     if (euid == d->uid && (wmwindowList->isGuiApp(d->pid)
                            || wmwindowList->isTrayApp(d->pid)
                            || wmwindowList->isDesktopEntryApp(d->pid))) {
+        qCDebug(app) << "Process" << d->pid << "is a GUI/Tray/Desktop app";
         d->apptype = kFilterApps;
     } else if (euid == d->uid) {
+        qCDebug(app) << "Process" << d->pid << "is a current user app";
         d->apptype = kFilterCurrentUser;
     }
 
@@ -277,11 +299,13 @@ void Process::readProcessInfo()
     d->networkBandwidthSample->addSample(new IOPSSampleFrame(netiops));
 
     d->valid = d->valid && ok;
+    qCDebug(app) << "Finished reading full info for pid" << d->pid << "valid:" << d->valid;
 }
 
 // read /proc/[pid]/stat
 bool Process::readStat()
 {
+    qCDebug(app) << "Reading stat for pid" << d->pid;
     bool ok {true};
     char path[256];
     QByteArray buf;
@@ -293,10 +317,14 @@ bool Process::readStat()
 
     errno = 0;
     sprintf(path, PROC_STAT_PATH, d->pid);
-    if(access(path, R_OK) != 0)    return !ok;     /* no such dirent (anymore) */
+    if(access(path, R_OK) != 0) {
+        qCWarning(app) << "Cannot access stat file for process" << d->pid;
+        return !ok;
+    }
         
     // open /proc/[pid]/stat
     if ((fd = open(path, O_RDONLY)) < 0) {
+        qCWarning(app) << "Failed to open stat file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("open %1 failed").arg(path));
         return !ok;
     }
@@ -305,6 +333,7 @@ bool Process::readStat()
     sz = read(fd, buf.data(), 1024);
     close(fd);
     if (sz < 0) {
+        qCWarning(app) << "Failed to read stat file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("read %1 failed").arg(path));
         return !ok;
     }
@@ -316,6 +345,7 @@ bool Process::readStat()
 
     pos = strrchr(buf.data(), ')');
     if (!pos) {
+        qCWarning(app) << "Invalid stat file format for process" << d->pid;
         return !ok;
     }
 
@@ -347,6 +377,7 @@ bool Process::readStat()
                 &d->guest_time, // 43
                 &d->cguest_time); // 44
     if (rc < 15) {
+        qCWarning(app) << "Failed to parse stat file for process" << d->pid << "Parsed fields:" << rc;
         return !ok;
     }
     // have guest & cguest time
@@ -354,12 +385,14 @@ bool Process::readStat()
         d->guest_time = d->cguest_time = 0;
     }
 
+    qCDebug(app) << "Successfully read stat for pid" << d->pid;
     return ok;
 }
 
 // read /proc/[pid]/cmdline
 bool Process::readCmdline()
 {
+    qCDebug(app) << "Reading cmdline for pid" << d->pid;
     bool ok = true;
     char path[128] {};
     const size_t bsiz = 4096;
@@ -369,18 +402,23 @@ bool Process::readCmdline()
     char *begin, *cur, *end;
 
     sprintf(path, PROC_CMDLINE_PATH, d->pid);
-    if(access(path, R_OK) != 0)    return !ok;     /* no such dirent (anymore) */
+    if(access(path, R_OK) != 0) {
+        qCWarning(app) << "Cannot access cmdline file for process" << d->pid;
+        return !ok;
+    }
 
     errno = 0;
     // open /proc/[pid]/cmdline
     uFile fp(fopen(path, "r"));
     if (!fp) {
+        qCWarning(app) << "Failed to open cmdline file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("open %1 failed").arg(path));
         return !ok;
     }
 
     nb = fread(cmd.data(), 1, bsiz - 1, fp.get());
     if (ferror(fp.get())) {
+        qCWarning(app) << "Failed to read cmdline file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("read %1 failed").arg(path));
         return !ok;
     }
@@ -403,12 +441,14 @@ bool Process::readCmdline()
         d->cmdline << buf;
     }
 
+    qCDebug(app) << "Successfully read cmdline for pid" << d->pid;
     return ok;
 }
 
 // read /proc/[pid]/environ
 void Process::readEnviron()
 {
+    qCDebug(app) << "Reading environ for pid" << d->pid;
     const size_t sz = 1024;
     char path[128] {};
     ssize_t nb;
@@ -417,12 +457,16 @@ void Process::readEnviron()
     int fd;
 
     sprintf(path, PROC_ENVIRON_PATH, d->pid);
-    if(access(path, R_OK) != 0)    return;     /* no such dirent (anymore) */
+    if(access(path, R_OK) != 0) {
+        // qCWarning(app) << "Cannot access environment file for process" << d->pid;
+        return;
+    }
 
     errno = 0;
     // open /proc/[pid]/environ
     fd = open(path, O_RDONLY);
     if (fd < 0) {
+        qCWarning(app) << "Failed to open environment file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("open %1 failed").arg(path));
         return;
     }
@@ -434,11 +478,13 @@ void Process::readEnviron()
     close(fd);
 
     if (nb == 0 && errno != 0) {
+        qCWarning(app) << "Failed to read environment file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("read %1 failed").arg(path));
         return;
     }
 
     if (sbuf.size() > 0) {
+        qCDebug(app) << "Processing environment variables for pid" << d->pid;
         auto elist = sbuf.split('\0');
         for (auto it : elist) {
             // it: name=value pair
@@ -447,12 +493,14 @@ void Process::readEnviron()
                 d->environ[kvp[0]] = kvp[1];
             }
         }
-    } // ::if(sbuf)
+    }
+    qCDebug(app) << "Finished reading environ for pid" << d->pid;
 }
 
 // read /proc/[pid]/schedstat
 void Process::readSchedStat()
 {
+    qCDebug(app) << "Reading schedstat for pid" << d->pid;
     const size_t bsiz = 1024;
     QByteArray buf;
     char path[128];
@@ -462,11 +510,15 @@ void Process::readSchedStat()
 
     buf.reserve(bsiz);
     sprintf(path, PROC_SCHEDSTAT_PATH, d->pid);
-    if(access(path, R_OK) != 0)    return;     /* no such dirent (anymore) */
+    if(access(path, R_OK) != 0) {
+        qCWarning(app) << "Cannot access schedstat file for process" << d->pid;
+        return;
+    }
 
     errno = 0;
     // open /proc/[pid]/schedstat
     if ((fd = open(path, O_RDONLY)) < 0) {
+        qCWarning(app) << "Failed to open schedstat file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("open %1 failed").arg(path));
         return;
     }
@@ -475,6 +527,7 @@ void Process::readSchedStat()
     close(fd);
 
     if (n < 0) {
+        qCWarning(app) << "Failed to read schedstat file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("read %1 failed").arg(path));
         return;
     }
@@ -483,7 +536,11 @@ void Process::readSchedStat()
     rc = sscanf(buf.data(), "%*u %llu %*d", &wtime);
     if (rc == 1) {
         d->wtime = wtime * HZ / 1000000000;
+        qCDebug(app) << "Successfully parsed schedstat for pid" << d->pid;
+    } else {
+        qCWarning(app) << "Failed to parse schedstat file for process" << d->pid;
     }
+    qCDebug(app) << "Finished reading schedstat for pid" << d->pid;
 }
 
 // read /proc/[pid]/status
@@ -496,12 +553,16 @@ bool Process::readStatus()
 
     buf.reserve(bsiz);
     sprintf(path, PROC_STATUS_PATH, d->pid);
-    if(access(path, R_OK) != 0)    return !ok;     /* no such dirent (anymore) */
+    if(access(path, R_OK) != 0) {
+        qCWarning(app) << "Cannot access status file for process" << d->pid;
+        return !ok;
+    }
 
     errno = 0;
     uFile fp(fopen(path, "r"));
     // open /proc/[pid]/status
     if (!fp) {
+        qCWarning(app) << "Failed to open status file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("open %1 failed").arg(path));
         return !ok;
     }
@@ -525,13 +586,15 @@ bool Process::readStatus()
                    &d->sgid,
                    &d->fgid);
         }
-    } // ::while(fgets)
+    }
 
     if (ferror(fp.get())) {
+        qCWarning(app) << "Failed to read status file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("read %1 failed").arg(path));
         return !ok;
     }
 
+    qCDebug(app) << "Successfully read status for pid" << d->pid;
     return ok;
 }
 
@@ -545,11 +608,15 @@ bool Process::readStatm()
     ssize_t nr;
 
     sprintf(path, PROC_STATM_PATH, d->pid);
-    if(access(path, R_OK) != 0)    return !ok;     /* no such dirent (anymore) */
+    if(access(path, R_OK) != 0) {
+        qCWarning(app) << "Cannot access statm file for process" << d->pid;
+        return !ok;
+    }
 
     errno = 0;
     // open /proc/[pid]/statm
     if ((fd = open(path, O_RDONLY)) < 0) {
+        qCWarning(app) << "Failed to open statm file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("open %1 failed").arg(path));
         return !ok;
     }
@@ -557,6 +624,7 @@ bool Process::readStatm()
     nr = read(fd, buf, bsiz);
     close(fd);
     if (nr < 0) {
+        qCWarning(app) << "Failed to read statm file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("read %1 failed").arg(path));
         return !ok;
     }
@@ -568,6 +636,7 @@ bool Process::readStatm()
         d->vmsize = 0;
         d->rss = 0;
         d->shm = 0;
+        qCWarning(app) << "Failed to parse statm file for process" << d->pid;
         print_errno(errno, QString("read %1 failed").arg(path));
     } else {
         // convert to kB
@@ -585,12 +654,16 @@ void Process::readIO()
     char path[128], buf[bsiz];
 
     sprintf(path, PROC_IO_PATH, d->pid);
-    if(access(path, R_OK) != 0)    return;     /* no such dirent (anymore) */
+    if(access(path, R_OK) != 0) {
+        // qCWarning(app) << "Cannot access IO file for process" << d->pid;
+        return;
+    }
 
     errno = 0;
     // open /proc/[pid]/io
     uFile fp(fopen(path, "r"));
     if (!fp) {
+        qCWarning(app) << "Failed to open IO file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("open %1 failed").arg(path));
         return;
     }
@@ -604,10 +677,13 @@ void Process::readIO()
         } else if (!strncmp(buf, "cancelled_write_bytes", 21)) {
             sscanf(buf + 23, "%llu", &d->cancelled_write_bytes);
         }
-    } // ::while(fgets)
+    }
     if (ferror(fp.get())) {
+        qCWarning(app) << "Failed to read IO file for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("read %1 failed").arg(path));
     }
+
+    qCDebug(app) << "Finished reading IO for pid" << d->pid;
 }
 
 // read /proc/[pid]/fd
@@ -618,12 +694,16 @@ void Process::readSockInodes()
     struct stat sbuf;
 
     sprintf(path, PROC_FD_PATH, d->pid);
-    if(access(path, R_OK) != 0)    return;     /* no such dirent (anymore) */
+    if(access(path, R_OK) != 0) {
+        // qCWarning(app) << "Cannot access fd directory for process" << d->pid;
+        return;
+    }
 
     errno = 0;
     // open /proc/[pid]/fd dir
     uDir dir(opendir(path));
     if (!dir) {
+        qCWarning(app) << "Failed to open fd directory for process" << d->pid << "Error:" << strerror(errno);
         print_errno(errno, QString("open %1 failed").arg(path));
         return;
     }
@@ -683,6 +763,7 @@ QString Process::name() const
 
 void Process::setName(const QString &name)
 {
+    // qCDebug(app) << "Set name for pid" << d->pid << "to" << name;
     d->name = name;
 }
 
