@@ -37,6 +37,8 @@ using namespace DDLog;
 
 static bool read_dmi_cache = false;
 
+using namespace DDLog;
+
 namespace core {
 namespace system {
 
@@ -48,8 +50,11 @@ namespace system {
  */
 static float first_avaliable_cur_freq(struct lscpu_cxt *cxt, const struct lscpu_cputype *ct)
 {
-    if (!cxt)
+    qCDebug(app) << "Getting first available current frequency";
+    if (!cxt) {
+        qCWarning(app) << "lscpu_cxt is null";
         return 0.0f;
+    }
 
     size_t i;
 
@@ -62,16 +67,21 @@ static float first_avaliable_cur_freq(struct lscpu_cxt *cxt, const struct lscpu_
             continue;
         if (cpu->mhz_cur_freq <= 0.0f)
             continue;
+        qCDebug(app) << "Found first available frequency:" << cpu->mhz_cur_freq << "at index" << i;
         return cpu->mhz_cur_freq;
     }
 
+    qCDebug(app) << "No available frequency found";
     return 0.0f;
 }
 // 取所有CPU频率有效值中最大值
 static float max_avaliable_cur_freq(struct lscpu_cxt *cxt, const struct lscpu_cputype *ct)
 {
-    if (!cxt)
+    qCDebug(app) << "Getting max available current frequency";
+    if (!cxt) {
+        qCWarning(app) << "lscpu_cxt is null";
         return 0.0f;
+    }
 
     size_t i;
     float res = 0.0f;
@@ -86,6 +96,7 @@ static float max_avaliable_cur_freq(struct lscpu_cxt *cxt, const struct lscpu_cp
         res = max(res, cpu->mhz_cur_freq);
     }
 
+    qCDebug(app) << "Max available frequency is" << res;
     return res;
 }
 
@@ -93,9 +104,12 @@ static void lscpu_free_context(struct lscpu_cxt *cxt)
 {
     size_t i;
 
-    if (!cxt)
+    if (!cxt) {
+        qCDebug(app) << "lscpu_cxt is null, skipping free";
         return;
+    }
 
+    qCDebug(app) << "Freeing lscpu context";
     DBG(MISC, ul_debugobj(cxt, "freeing context"));
 
     DBG(MISC, ul_debugobj(cxt, " de-initialize paths"));
@@ -137,6 +151,7 @@ static void lscpu_free_context(struct lscpu_cxt *cxt)
     lscpu_free_caches(cxt->caches, cxt->ncaches);
 
     free(cxt);
+    qCDebug(app) << "Freed lscpu context";
 }
 /*
 * borrowed & modified from LINUX bitmap.c
@@ -315,15 +330,18 @@ static void lscpu_free_context(struct lscpu_cxt *cxt)
 CPUSet::CPUSet()
     : d(new CPUSetPrivate())
 {
+    qCDebug(app) << "CPUSet constructor";
 }
 
 CPUSet::CPUSet(const CPUSet &other)
     : d(other.d)
 {
+    qCDebug(app) << "CPUSet copy constructor";
 }
 
 CPUSet &CPUSet::operator=(const CPUSet &rhs)
 {
+    qCDebug(app) << "CPUSet assignment operator";
     if (this == &rhs)
         return *this;
 
@@ -333,10 +351,13 @@ CPUSet &CPUSet::operator=(const CPUSet &rhs)
 
 CPUSet::~CPUSet()
 {
+    qCDebug(app) << "CPUSet destructor";
+    // NOTE: don't delete d here, it's a shared pointer
 }
 
 QString CPUSet::modelName() const
 {
+    qCDebug(app) << "Getting CPU model name";
     if (mIsEmptyModelName == true)
         return d->m_info.value(QStringLiteral("型号名称"));
     else
@@ -345,6 +366,7 @@ QString CPUSet::modelName() const
 
 QString CPUSet::vendor() const
 {
+    qCDebug(app) << "Getting CPU vendor";
     if (mIsEmptyModelName == true)
         return d->m_info.value(QStringLiteral("厂商 ID"));
     else
@@ -353,28 +375,35 @@ QString CPUSet::vendor() const
 
 int CPUSet::cpuCount() const
 {
+    qCDebug(app) << "Getting CPU count";
     return d->m_info.value("CPU(s)").toInt();
 }
 
 int CPUSet::socketCount() const
 {
+    qCDebug(app) << "Getting CPU socket count";
     return d->m_info.value("Socket(s)").toInt();
 }
 
 QString CPUSet::virtualization() const
 {
+    qCDebug(app) << "Getting CPU virtualization";
     return d->m_info.value("Virtualization").isEmpty() ? QObject::tr("Not support") : d->m_info.value("Virtualization");
 }
 
 QString CPUSet::curFreq() const
 {
-    if (d->m_info.value("CPU MHz") == "-")
+    qCDebug(app) << "Getting current CPU frequency";
+    if (d->m_info.value("CPU MHz") == "-") {
+        qCDebug(app) << "Current CPU frequency not available";
         return "-";
+    }
     return common::format::formatHz(d->m_info.value("CPU MHz").toDouble(), common::format::MHz);
 }
 
 QString CPUSet::minFreq() const
 {
+    qCDebug(app) << "Getting min CPU frequency";
     if (mIsEmptyModelName == true)
         return common::format::formatHz(d->m_info.value(QStringLiteral("CPU 最小 MHz")).toDouble(), common::format::MHz);
     else
@@ -383,6 +412,7 @@ QString CPUSet::minFreq() const
 
 QString CPUSet::maxFreq() const
 {
+    qCDebug(app) << "Getting max CPU frequency";
     //获取最大CPU频率数值，单位MHz
     qreal MaxFreq = mIsEmptyModelName ? d->m_info.value(QStringLiteral("CPU 最大 MHz")).toDouble() : d->m_info.value("CPU max MHz").toDouble();
     return common::format::formatHz(static_cast<uint>(MaxFreq), common::format::MHz);
@@ -390,101 +420,122 @@ QString CPUSet::maxFreq() const
 
 QString CPUSet::l1dCache() const
 {
+    qCDebug(app) << "Getting L1d cache";
     auto list = d->m_info.keys();
     QString key = "";
     foreach (QString tmpKey, list) {
         if (tmpKey.contains("L1d")) {
             key = tmpKey;
+            qCDebug(app) << "Found L1d cache key:" << key;
             break;
         }
     }
     QString value = d->m_info.value(key);
+    qCDebug(app) << "L1d cache value:" << value;
     return value.isNull() ? "-" : value;
 }
 
 QString CPUSet::l1iCache() const
 {
+    qCDebug(app) << "Getting L1i cache";
     auto list = d->m_info.keys();
     QString key = "";
     foreach (QString tmpKey, list) {
         if (tmpKey.contains("L1i")) {
             key = tmpKey;
+            qCDebug(app) << "Found L1i cache key:" << key;
             break;
         }
     }
     QString value = d->m_info.value(key);
+    qCDebug(app) << "L1i cache value:" << value;
     return value.isNull() ? "-" : value;
 }
 
 QString CPUSet::l2Cache() const
 {
+    qCDebug(app) << "Getting L2 cache";
     auto list = d->m_info.keys();
     QString key = "";
     foreach (QString tmpKey, list) {
         if (tmpKey.contains("L2")) {
             key = tmpKey;
+            qCDebug(app) << "Found L2 cache key:" << key;
             break;
         }
     }
     QString value = d->m_info.value(key);
+    qCDebug(app) << "L2 cache value:" << value;
     return value.isNull() ? "-" : value;
 }
 
 QString CPUSet::l3Cache() const
 {
+    qCDebug(app) << "Getting L3 cache";
     auto list = d->m_info.keys();
     QString key = "";
     foreach (QString tmpKey, list) {
         if (tmpKey.contains("L3")) {
             key = tmpKey;
+            qCDebug(app) << "Found L3 cache key:" << key;
             break;
         }
     }
     QString value = d->m_info.value(key);
+    qCDebug(app) << "L3 cache value:" << value;
     return value.isNull() ? "-" : value;
 }
 
 QString CPUSet::coreId(int index) const
 {
+    qCDebug(app) << "Getting core ID for index" << index;
     return d->m_infos.value(index).coreID();
 }
 
 const CPUUsage CPUSet::usage() const
 {
+    qCDebug(app) << "Getting overall CPU usage";
     return d->m_usage;
 }
 
 const CPUStat CPUSet::stat() const
 {
+    qCDebug(app) << "Getting overall CPU stat";
     return d->m_stat;
 }
 
 QList<QByteArray> CPUSet::cpuLogicName() const
 {
+    qCDebug(app) << "Getting CPU logical names";
     return d->m_usageDB.keys();
 }
 
 const CPUStat CPUSet::statDB(const QByteArray &cpu) const
 {
+    qCDebug(app) << "Getting CPU stat for" << cpu;
     return d->m_statDB[cpu];
 }
 
 const CPUUsage CPUSet::usageDB(const QByteArray &cpu) const
 {
+    qCDebug(app) << "Getting CPU usage for" << cpu;
     return d->m_usageDB[cpu];
 }
 
 void CPUSet::update()
 {
+    qCDebug(app) << "Updating CPUSet...";
     read_stats();
     read_overall_info();
 
     d->cpusageTotal[kLastStat] = d->cpusageTotal[kCurrentStat];
     d->cpusageTotal[kCurrentStat] = d->m_usage->total;
+    qCDebug(app) << "CPUSet update finished.";
 }
 
 void CPUSet::read_stats()
 {
+    qCDebug(app) << "Reading CPU stats from" << PROC_PATH_STAT;
     FILE *fp;
     uFile fPtr;
     QByteArray line(BUFSIZ, '\0');
@@ -500,6 +551,7 @@ void CPUSet::read_stats()
     while (fgets(line.data(), BUFSIZ, fp)) {
         if (!strncmp(line.data(), "cpu ", 4)) {
             if (!d->m_stat) {
+                // qCDebug(app) << "Allocating overall cpu_stat_t";
                 d->m_stat = std::make_shared<struct cpu_stat_t>();
                 *d->m_stat = {};
             }
@@ -519,11 +571,13 @@ void CPUSet::read_stats()
                             &d->m_stat->guest_nice);
 
                 if (nr == 10) {
+                    // qCDebug(app) << "Successfully parsed overall CPU stats.";
                     // usage calc
                     QByteArray cpu { "cpu" };
                     d->m_stat->cpu = cpu;
 
                     if (!d->m_usage) {
+                        // qCDebug(app) << "Allocating overall cpu_usage_t";
                         d->m_usage = std::make_shared<struct cpu_usage_t>();
                         *d->m_usage = {};
                     }
@@ -560,6 +614,7 @@ void CPUSet::read_stats()
                     QByteArray cpu { "cpu" };
                     cpu.append(QByteArray::number(ncpu));
                     stat->cpu = cpu;
+                    // qCDebug(app) << "Successfully parsed stats for" << cpu;
 
                     // usage calc
                     auto usage = std::make_shared<struct cpu_usage_t>();
@@ -584,6 +639,7 @@ void CPUSet::read_stats()
             if (nm == 1) {
                 btime.tv_sec = nsec;
                 btime.tv_usec = 0;
+                // qCDebug(app) << "Parsed boot time:" << btime.tv_sec;
 
                 // set sysinfo btime
                 auto *monitor = ThreadManager::instance()->thread<SystemMonitorThread>(BaseThread::kSystemMonitorThread)->systemMonitorInstance();
@@ -595,10 +651,12 @@ void CPUSet::read_stats()
     if (ferror(fp)) {
         qCWarning(app) << "Error reading" << PROC_PATH_STAT << ":" << strerror(errno);
     }
+    qCDebug(app) << "Finished reading CPU stats.";
 }
 
 void CPUSet::read_overall_info()
 {
+    qCDebug(app) << "Reading overall CPU info from /proc/cpuinfo...";
     //proc/cpuinfo
     QList<CPUInfo> infos;
     QProcess process;
@@ -610,8 +668,10 @@ void CPUSet::read_overall_info()
 #else
     QStringList processors = cpuinfo.split("\n\n", Qt::SkipEmptyParts);
 #endif
+    qCDebug(app) << "Found" << processors.count() << "processors in /proc/cpuinfo";
 
     for (int i = 0; i < processors.count(); ++i) {
+        // qCDebug(app) << "Parsing processor" << i;
         CPUInfo info;
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QStringList list = processors[i].split("\n", QString::SkipEmptyParts);
@@ -635,6 +695,7 @@ void CPUSet::read_overall_info()
         }
         infos.append(info);
     }
+    qCDebug(app) << "Finished parsing /proc/cpuinfo";
 
     //    if (!cpuinfo.contains("model name")) {
     //        mIsEmptyModelName = true;
@@ -665,12 +726,15 @@ void CPUSet::read_overall_info()
     //    }
     read_lscpu();
     d->m_infos = infos;
+    qCDebug(app) << "Finished reading overall CPU info.";
 }
 
 void CPUSet::read_dmi_cache_info()
 {
+    qCDebug(app) << "Reading DMI cache info...";
     if (read_dmi_cache || (d->m_info.contains("L1d cache") && d->m_info.contains("L1i cache") && d->m_info.contains("L2 cache") && d->m_info.contains("L3 cache"))) {
         read_dmi_cache = true;
+        qCDebug(app) << "DMI cache info already read or found in lscpu, skipping.";
         return;
     }
 
@@ -797,6 +861,7 @@ void CPUSet::read_dmi_cache_info()
 // 获取CPU信息 ut001987
 void CPUSet::read_lscpu()
 {
+    qCDebug(app) << "Reading CPU info using lscpu library...";
     struct lscpu_cxt *cxt;   // CPU信息
     cxt = reinterpret_cast<struct lscpu_cxt *>(xcalloc(1, sizeof(struct lscpu_cxt)));   // 初始化信息
     if (!cxt) {
@@ -805,6 +870,7 @@ void CPUSet::read_lscpu()
     }
     /* set default cpu display mode if none was specified */
     if (!cxt->show_online && !cxt->show_offline) {
+        qCDebug(app) << "Setting default CPU display mode";
         cxt->show_online = 1;
         cxt->show_offline = cxt->mode == LSCPU_OUTPUT_READABLE ? 1 : 0;
     }
@@ -812,6 +878,7 @@ void CPUSet::read_lscpu()
     cxt->syscpu = ul_new_path(_PATH_SYS_CPU);
     if (!cxt->syscpu) {
         qCWarning(app) << "Failed to initialize CPUs sysfs handler";
+        lscpu_free_context(cxt);
         return;
     }
 
@@ -820,26 +887,33 @@ void CPUSet::read_lscpu()
     cxt->procfs = ul_new_path("/proc");
     if (!cxt->procfs) {
         qCWarning(app) << "Failed to initialize procfs handler";
+        lscpu_free_context(cxt);
         return;
     }
 
     if (cxt->prefix)
         ul_path_set_prefix(cxt->procfs, cxt->prefix);
 
+    qCDebug(app) << "lscpu context initialized. Reading CPU lists and info...";
     lscpu_read_cpulists(cxt);
     lscpu_read_cpuinfo(cxt);
+    qCDebug(app) << "Finished reading CPU lists and info.";
 
     cxt->arch = lscpu_read_architecture(cxt);
+    qCDebug(app) << "Read architecture:" << (cxt->arch ? cxt->arch->name : "N/A");
     // 获取CPU的相关信息
     lscpu_read_archext(cxt);
     lscpu_read_vulnerabilities(cxt);
     lscpu_read_numas(cxt);
     lscpu_read_topology(cxt);
+    qCDebug(app) << "Read topology and other extensions.";
     lscpu_decode_arm(cxt);
     cxt->virt = lscpu_read_virtualization(cxt);   // 获取CPU的虚拟化信息
+    qCDebug(app) << "Read virtualization info:" << (cxt->virt && cxt->virt->hypervisor ? cxt->virt->hypervisor : "N/A");
     struct lscpu_cputype *ct;
     ct = lscpu_cputype_get_default(cxt);   // 获取CPU类型信息
     if (ct) {
+        qCDebug(app) << "Default CPU type found. Populating info map.";
         if (cxt->arch)
             d->m_info.insert("Architecture", cxt->arch->name);
         // cpu架构信息
@@ -871,11 +945,14 @@ void CPUSet::read_lscpu()
             size_t setbuflen = static_cast<size_t>(7 * cxt->maxcpus);
             char setbuf[setbuflen], *p;
             if (cxt->hex) {
+                qCDebug(app) << "Creating hex cpumask for online CPUs";
                 p = cpumask_create(setbuf, setbuflen, cxt->online, cxt->setsize);
             } else {
+                qCDebug(app) << "Creating list for online CPUs";
                 p = cpulist_create(setbuf, setbuflen, cxt->online, cxt->setsize);
             }
             d->m_info.insert(key, p);
+            qCDebug(app) << key << ":" << p;
         }
 
         // CPU厂商信息
@@ -887,8 +964,10 @@ void CPUSet::read_lscpu()
                 d->m_info.insert("Vendor ID", "-");
             else
                 d->m_info.insert("Vendor ID", ct->vendor);
-        } else
+        } else {
             d->m_info.insert("Vendor ID", "-");
+            qCDebug(app) << "Vendor ID not found";
+        }
 
         if (ct && ct->bios_vendor) {   //  BIOS厂商信息
             d->m_info.insert("BIOS Vendor ID", ct->bios_vendor);
@@ -962,6 +1041,7 @@ void CPUSet::read_lscpu()
                 nowMHz = "-";
             }
             d->m_info.insert("CPU MHz", nowMHz);
+            qCDebug(app) << "Populated frequency: Min=" << minMHz << "Max=" << maxMHz << "Current=" << nowMHz;
         } else {
             if (CurrentCPUFreq > 0) {
                 d->m_info.insert("CPU MHz", QString::number(CurrentCPUFreq));
@@ -998,6 +1078,7 @@ void CPUSet::read_lscpu()
             d->m_info.insert("Hypervisor", "cxt->virt->hypervisor");
         }
     }
+    qCDebug(app) << "Populating cache information...";
     /* Section: caches */
     if (cxt->ncaches) {
         const char *last = nullptr;
@@ -1058,6 +1139,7 @@ void CPUSet::read_lscpu()
         }
     }
     lscpu_free_context(cxt);
+    qCDebug(app) << "Finished reading CPU info using lscpu library.";
 }
 
 qulonglong CPUSet::getUsageTotalDelta() const
